pub fn list_pop(coll: &RuntimeValue) -> Result<RuntimeValue, String>Expand description
Pop from list — removes and returns the last element, or Nothing when
the list is empty (popping an empty list is NOT an error).
pub fn list_pop(coll: &RuntimeValue) -> Result<RuntimeValue, String>Pop from list — removes and returns the last element, or Nothing when
the list is empty (popping an empty list is NOT an error).