pub fn reference_scope_active() -> boolExpand description
Whether the current thread is inside a ReferenceScope. Consulted by the
AOT runner so a child process compiled from PE source inherits reference
semantics (LOGOS_VALUE_SEMANTICS=0).
pub fn reference_scope_active() -> boolWhether the current thread is inside a ReferenceScope. Consulted by the
AOT runner so a child process compiled from PE source inherits reference
semantics (LOGOS_VALUE_SEMANTICS=0).